% Animation of electromagnetic plane waves propagating in +z direction.
%
% Complement to Figure 2.2 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define wavelength [m].
lambda = 1;

% Calculate constants.
c = 2.99792458e8;   % speed of light in vacuum [m/s]
freq = c/lambda;    % frequency from wavelength [Hz]
T = 1/freq;         % time of a period [s]
omega = 2*pi*freq;  % angular frequency [rad/s]
k = 2*pi/lambda;    % wave number [rad/m]

% Define co-polarization vectors for x-linear and right hand circular
% polarizations from Eq. (2.18).
lin_co_hat = [1 ;   0];
rhc_co_hat = [1 ; -1j] / sqrt(2);

% Define z-coordinates for propagation sequence.
z = 0:0.02:3;

% Calculate E-field vectors. The first dimension is the x- and y-components of
% the electric field. The second dimension is the propagation distance z.
E_lin = lin_co_hat * exp(-1j*k*z);  % Eq. (2.8)
E_rhc = rhc_co_hat * exp(-1j*k*z);  % Eq. (2.8)

% Help vector for plotting from z-axis.
zer = zeros(1, numel(z));

% Open a new figure and start the animation loop. Allow user to stop the
% animation at any time by clicking on the figure.
h = figure;
stop_animation = false;
set(h, 'WindowButtonDownFcn', 'stop_animation = true;');
for t = 0:0.05:5
    
    % Calculate instantaneous E-fields from Eq. (2.2).
    E_lin_time = real(E_lin * exp(1j*omega*t*T));
    E_rhc_time = real(E_rhc * exp(1j*omega*t*T));

    % Plot E-field in three dimensional plots.
    subplot(1, 2, 1);
    plot3(E_lin_time(1,:), E_lin_time(2,:), z, 'b-', ...
        [zer ; E_lin_time(1,:)], [zer ; E_lin_time(2,:)], [z ; z], 'k-');
    view(-30, 30);
    axis([-1 1 -1 1 0 3]);
    grid on;
    title(sprintf('x-polarization, t = %.2f T', t));
    xlabel('x');
    ylabel('y');
    zlabel('z');

    % Plot E-field in three dimensional plots.
    subplot(1, 2, 2);
    plot3(E_rhc_time(1,:), E_rhc_time(2,:), z, 'b-', ...
        [zer ; E_rhc_time(1,:)], [zer ; E_rhc_time(2,:)], [z ; z], 'k-');
    view(-30, 30);
    axis([-1 1 -1 1 0 3]);
    grid on;
    title(sprintf('RHC-polarization, t = %.2f T', t));
    xlabel('x');
    ylabel('y');
    zlabel('z');
    
    % Update plot and pause to get a smooth animation.
    drawnow;
    pause(0.02);
    
    % Have the user clicked on the animation to stop it?
    if stop_animation, break; end %#ok<UNRCH>

    % Make "publish_all.m" faster.
    if exist('pub_d', 'var'), break; end
end
