% Amplitude and phase errors in circular polarization excitations.
%
% Complement to Figure 2.3 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Amplitude of y-polarized plane wave (from Section 2.2.4).
A_dB = 0:0.02:10;
A = 10.^(A_dB/20);

% Phase error of y-polarized plane wave (from Section 2.2.4).
Delta_phi_deg = 0:0.1:50;

% Co- and cross-polar levels for LHC-polarization (from Section 2.2.4).
E_co = (1 + A' * exp(1j*Delta_phi_deg*pi/180)) / sqrt(2);
E_xp = (1 - A' * exp(1j*Delta_phi_deg*pi/180)) / sqrt(2);

% Relative cross-polar level.
XP = abs(E_xp./E_co).^2;  % Eq. (2.36) in linear power scale
XP_dB = 10*log10(XP);

% Minimum level in plots.
ymin_dB = -40;
XP_dB_plot = max(XP_dB, ymin_dB);

% Plot XP level as a function of amplitude error.
figure;
icol = find(Delta_phi_deg==0,1);  % phase error==0
plot(A_dB, XP_dB(:,icol));
axis([min(A_dB) max(A_dB) ymin_dB 0]);
grid on;
xlabel('Amplitude error [dB]');
ylabel('Relative cross-polar level [dB]');

% Plot XP level as a function of phase error.
figure;
irow = find(A==1,1);  % amplitude==1
plot(Delta_phi_deg, XP_dB(irow,:));
axis([min(Delta_phi_deg) max(Delta_phi_deg) ymin_dB 0]);
grid on;
xlabel('Phase error [deg]');
ylabel('Relative cross-polar level [dB]');

% Plot both amplitude and phase error.
figure;
XP_dB_plot(end,end) = -100;  % hack to avoid graphic glitch when saving plot
surf(Delta_phi_deg, A_dB, XP_dB_plot);
view([0 90]);
colormap(jet(-ymin_dB/2.5));
set(gca, 'TickDir', 'out');
grid off;
box on;
caxis([ymin_dB 0]);
shading flat;
colorbar;
title('Relative cross-polar level [dB]');
xlabel('Phase error [deg]');
ylabel('Amplitude error [dB]');
if exist('savefigs', 'var') && savefigs
    save_fig('fig_02_03.png', 14, 10, 450);
    colormap(flipud(gray(-ymin_dB/5)));
    save_fig('fig_02_03_gray.png', 14, 10, 450);
end
