% Directivity for the "cosn" far-field function.
%
% Complement to Figure 2.15 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Reproduce Figure 2.15.
bw_levels_dB = [-3 -10 -20]';
half_bw = logspace(log10(0.1*pi/180), log10(100*pi/180), 200);
n = bsxfun(@rdivide, bw_levels_dB, 20*log10(cos(half_bw/2)));
D0_dB = 10*log10(n + 1);  % directivity

figure;
semilogx(half_bw*180/pi, D0_dB);
grid on;
xlabel('Half beam width [deg]');
ylabel('Directivity [dB]');
axis([0.1 100 0 60]);
set(gca, 'XTick', 10.^(-1:2));
set(gca, 'XTickLabel', {'0.1','1','10','100'});
lgnds = cell(size(bw_levels_dB));
for ii = 1:numel(bw_levels_dB)
    lgnds{ii} = sprintf('%.0f dB', bw_levels_dB(ii));
end
legend(lgnds);

% Different E- and H-plane beam widths.
half_bw_eplane = (0.1:0.01:100)*pi/180;
half_bw_hplane = [0.1 0.2 0.5 1 2 5 10 20 50 100]*pi/180;
half_bw_mat = bsxfun(@hypot, half_bw_eplane', half_bw_hplane) / sqrt(2);
n_mat = -3 ./ (20*log10(cos(half_bw_mat/2)));
D0_mat_dB = 10*log10(n_mat + 1);  % directivity

figure;
semilogx(half_bw_eplane*180/pi, D0_mat_dB);
grid on;
xlabel('Half beam width E-plane [deg]');
ylabel('Directivity [dB]');
axis([0.1 100 0 60]);
set(gca, 'XTick', 10.^(-1:2));
set(gca, 'XTickLabel', {'0.1','1','10','100'});
lgnds = cell(1,size(half_bw_mat,2));
for ii = 1:numel(lgnds)
    lgnds{ii} = sprintf('H-plane half beam width %.1f deg', ...
        half_bw_hplane(ii)*180/pi);
end
legend(lgnds);

% Plot radiation pattern for different E- and H-plane beam widths.
half_bw_eplane_deg = 10;
half_bw_hplane_deg = [2 5 10 20 50];
theta_deg = -180:180;
phi_deg = 0:180;
half_bw_eplane = half_bw_eplane_deg*pi/180;
[theta, phi, half_bw_hplane] = ndgrid(theta_deg*pi/180, phi_deg*pi/180, ...
    half_bw_hplane_deg*pi/180);
ne = -3 ./ (20*log10(cos(half_bw_eplane/2)));
nh = -3 ./ (20*log10(cos(half_bw_hplane/2)));
G_theta = cos(theta/2).^ne .* sin(phi);
G_phi   = cos(theta/2).^nh .* cos(phi);
for ii = 1:numel(half_bw_hplane_deg)
    plot_3d_farfield(theta(:,:,ii), phi(:,:,ii), ...
        G_theta(:,:,ii), G_phi(:,:,ii), 'yprim');
    annotation('textbox', [0.05,0.05,0.9,0.08], 'string', sprintf([...
        'Half beamwidth E-plane = %.0f deg, ' ...
        'Half beamwidth H-plane = %.0f deg'], ...
        half_bw_eplane_deg, half_bw_hplane_deg(ii)), ...
        'HorizontalAlignment', 'center');
end
