% S-parameters and efficiencies from mutual impedance of two parallel dipoles.
%
% Complement to Figure 3.6 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
a = 0.006;             % radius for self impedance calculation [lambda]
d = (0.04:0.01:0.5)';  % separation [lambda]
len = 0.47;            % length of dipoles [lambda], must be close to 0.5

% Define some parameters and current on dipoles.
k = 2*pi;
eta = 120*pi;
Ck = -1j*k/(4*pi);
zp = linspace(-len/2, len/2, 401);
dzp = zp(2) - zp(1);
[add, zzp] = ndgrid([a ; d], zp);
curr = sin(k*(len-2*abs(zzp))/2) ./ sin(k*len/2);

% Side-by-side dipoles. Calculate double integral.
E1 = zeros(size(add));
for ii = 1:numel(zp)
    z = zp(ii);
    R = hypot(add, z-zzp);
    CN1 = 1 + 1./(1j*k*R) - 1./(k*R).^2;
    CN2 = 1 + 3./(1j*k*R) - 3./(k*R).^2;
    int = (CN1 - CN2.*((z-zzp)./R).^2) ./ R;
    E1(:,ii) = Ck * eta * dzp * trapz(curr.*int.*exp(-1j*k*R), 2);
end
Ztmp = dzp * trapz(-curr.*E1, 2);

% Self impedance and mutal impedance from calculation above.
Z11 = Ztmp(1);
Z12 = Ztmp(2:end);
Z21 = Z12;
Z22 = Z11;

% Convert Z-parameters to S-paramters.
Z0 = 50;
Delta = (Z11+Z0) .* (Z22+Z0) - Z12.*Z21;
S11 = ((Z11-Z0).*(Z22+Z0)-Z12.*Z21) ./ Delta;
S12 = 2*Z0*Z12 ./ Delta;

% Calculate efficiencies from Eq. (3.7).
e_refl = 1 - abs(S11).^2;
e_rad  = e_refl - abs(S12).^2;
e_abs  = e_rad ./ e_refl;

% Plot result for side-by-side dipoles.
figure;

subplot(1,2,1);
plot(d, 20*log10(abs(S11)), 'b-.', 'LineWidth', 1); hold on;
plot(d, 20*log10(abs(S12)), 'r--', 'LineWidth', 1);
axis([0 max(d) -20 0]);
grid on;
xlabel('Separation d/\lambda (-)');
ylabel('S-parameters (dB)');
legend('S11', 'S12', 'Location', 'northeast');

subplot(1,2,2);
plot(d, 10*log10(e_refl), 'b-.', 'LineWidth', 1); hold on;
plot(d, 10*log10(e_abs ), 'r--', 'LineWidth', 1);
plot(d, 10*log10(e_rad ), 'k-' , 'LineWidth', 1);
axis([0 max(d) -4 0]);
grid on;
xlabel('Separation d/\lambda (-)');
ylabel('Efficiency (dB)');
legend('Reflection', 'Absorption', 'Total', 'Location', 'southeast');
if exist('savefigs', 'var') && savefigs
    save_fig('fig_03_06.eps', 12.5*1.3, 7.5*1.3);
end
