% Diversity gain of two dipoles.
%
% Complement to Figure 3.9 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
eff_rad_dB = -1;  % radiation efficiency of dipoles
pos = [0.1 0 0];  % xyz-coordinates distances of dipole separation in lambda
n_waves_per_realization = 20;
n_realizations = 30e3;

% Reset random generator to be able to reproduce plots exactly.
reset(RandStream.getGlobalStream, 123);

% Far-field function of a z-directed incremental electric dipole in origin.
[theta, phi] = ndgrid((0:180)*pi/180, (-180:180)*pi/180);
Eth1 = 10.^(eff_rad_dB/20) * sqrt(1.5) * sin(theta);
Eph1 = zeros(size(Eth1));

% Define a second dipole with translated position. Assume no mutual coupling.
phase_change = exp(2j*pi*( pos(1)*sin(theta).*cos(phi) + ...
    pos(2)*sin(theta).*sin(phi) + pos(3)*cos(theta) ));
Eth2 = Eth1 .* phase_change;
Eph2 = Eph1 .* phase_change;

% Generate incoming plane waves (isotropic environment).
theta_waves = acos( 1 - 2*rand(n_waves_per_realization,n_realizations) );
phi_waves = 2*pi*rand(n_waves_per_realization,n_realizations) - pi;

% Define amplitude and phase of incoming waves.
amp = complex(randn(n_waves_per_realization,n_realizations), ...
              randn(n_waves_per_realization,n_realizations));
amp = amp ./ repmat(sqrt(sum(abs(amp).^2,1)), n_waves_per_realization, 1);
psi = 2*pi*rand(n_waves_per_realization,n_realizations);
Eth_waves = cos(psi) .* amp;
Eph_waves = sin(psi) .* amp;

% Evaluate complex received voltage at each antenna port.
v1 = sum( interp2(phi,theta,Eth1,phi_waves,theta_waves) .* Eth_waves + ...
          interp2(phi,theta,Eph1,phi_waves,theta_waves) .* Eph_waves, 1);
v2 = sum( interp2(phi,theta,Eth2,phi_waves,theta_waves) .* Eth_waves + ...
          interp2(phi,theta,Eph2,phi_waves,theta_waves) .* Eph_waves, 1);

% Diversity combined signal.
%v_diversity = max(v1, v2);  % selection combination
v_diversity = sqrt(abs(v1).^2 + abs(v2).^2);  % maximum ratio combination

% Prepare for CDF plots.
v1_dB_sorted = sort(20*log10(abs(v1)));
v2_dB_sorted = sort(20*log10(abs(v2)));
v_diversity_dB_sorted = sort(20*log10(abs(v_diversity)));
cdf = (1:n_realizations) / n_realizations;

% Generate theoretical Rayleigh distribution.
v_theory_dB = -30:10;
v_theory = 10.^(v_theory_dB/20);
cdf_theory = 1 - exp(-v_theory.^2);

% Plot CDF:s.
figure;
semilogy(v_theory_dB, cdf_theory, 'k-', 'LineWidth', 1); hold on;
semilogy(v1_dB_sorted, cdf, 'r-', 'LineWidth', 2);
semilogy(v2_dB_sorted, cdf, 'b--', 'LineWidth', 2);
semilogy(v_diversity_dB_sorted, cdf, 'k--', 'LineWidth', 1);
xlim([-30 0]);
ylim([1e-3 1e0]);
grid off;
tmp = sprintf(' %g%%',100*get(gca,'YTick'));
set(gca, 'YTickLabel', strsplit(tmp(2:end)));
xlabel('Power level (dB)');
ylabel('Cumulative probability (-)');
legend('Theoretical Rayleigh', 'Port 1', 'Port 2', 'MRC', ...
    'Location', 'northwest');

% Create annotations.
annotation(gcf, 'doublearrow', [0.280 0.390], [0.3809 0.3809]);
annotation(gcf, 'textarrow',   [0.310 0.346], [0.6380 0.3905], ...
    'String', 'Total efficiency port 1 and 2');
annotation(gcf, 'doublearrow', [0.390 0.472], [0.3809 0.3809]);
annotation(gcf, 'textarrow',   [0.530 0.425], [0.4600 0.3976], ...
    'String', 'Effective diversity gain at 1 %');
annotation(gcf, 'doublearrow', [0.210 0.425], [0.3000 0.3000]);
annotation(gcf, 'textarrow',   [0.457 0.331], [0.1810 0.2943], ...
    'String', 'Diversity gain at 0.5 %');

% Save figure.
if exist('savefigs', 'var') && savefigs
    save_fig('Fig3-09.eps', 10*1.3, 7.5*1.3);
end
