% Correlation and diversity gain of two parallel dipoles.
%
% Complement to Figure 3.10 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
a = 0.006;             % radius for self impedance calculation [lambda]
d = (0.04:0.01:0.5)';  % separation [lambda]
len = 0.47;            % length of dipoles [lambda], must be close to 0.5

% Define some parameters and current on dipoles.
k = 2*pi;
eta = 120*pi;
Ck = -1j*k/(4*pi);
zp = linspace(-len/2, len/2, 401);
dzp = zp(2) - zp(1);
[add, zzp] = ndgrid([a ; d], zp);
curr = sin(k*(len-2*abs(zzp))/2) ./ sin(k*len/2);

% Side-by-side dipoles. Calculate double integral.
E1 = zeros(size(add));
for ii = 1:numel(zp)
    z = zp(ii);
    R = hypot(add, z-zzp);
    CN1 = 1 + 1./(1j*k*R) - 1./(k*R).^2;
    CN2 = 1 + 3./(1j*k*R) - 3./(k*R).^2;
    int = (CN1 - CN2.*((z-zzp)./R).^2) ./ R;
    E1(:,ii) = Ck * eta * dzp * trapz(curr.*int.*exp(-1j*k*R), 2);
end
Ztmp = dzp * trapz(-curr.*E1, 2);

% Self impedance and mutal impedance from calculation above.
Z11 = Ztmp(1);
Z12 = Ztmp(2:end);
Z21 = Z12;
Z22 = Z11;

% Convert Z-parameters to S-paramters.
Z0 = 50;
Delta = (Z11+Z0) .* (Z22+Z0) - Z12.*Z21;
S11 = ((Z11-Z0).*(Z22+Z0)-Z12.*Z21) ./ Delta;
S22 = ((Z11+Z0).*(Z22-Z0)-Z12.*Z21) ./ Delta;
S12 = 2*Z0*Z12 ./ Delta;
S21 = 2*Z0*Z21 ./ Delta;

% Calculate correlation from Eq. (3.10).
tmp0 = conj(S11).*S12 + conj(S21).*S22;
tmp1 = 1 - abs(S11).^2 - abs(S21).^2;
tmp2 = 1 - abs(S12).^2 - abs(S22).^2;
rho = -tmp0 ./ sqrt(tmp1.*tmp2);

% Calculate apparent and effective diversity gain.
AdgMrc_max = 14.78;
ee = 1;  % e_min/e_max
G_app = sqrt((1+ee).^2 + (AdgMrc_max.^2-4)*ee*(1-abs(rho).^2));
e_rad = 1 - abs(S11).^2 - abs(S12).^2;
G_eff = e_rad .* G_app;

% Plot result for side-by-side dipoles.
figure;

subplot(1,2,1);
plot(d, abs(rho), 'k-', 'LineWidth', 1);
axis([0 max(d) 0 1]);
grid on;
xlabel('Separation d/\lambda (-)');
ylabel('Amplitude of correlation (-)');

subplot(1,2,2);
plot(d, 10*log10(G_app), 'k-' , 'LineWidth', 1); hold on;
plot(d, 10*log10(G_eff), 'r--', 'LineWidth', 1);
axis([0 max(d) 3 12]);
grid on;
xlabel('Separation d/\lambda (-)');
ylabel('Diversity gain (dB)');
legend('Apparent diversity gain', 'Effective diversity gain', ...
    'Location', 'southwest');
if exist('savefigs', 'var') && savefigs
    save_fig('Fig3-10.eps', 12.5*1.3, 7.5*1.3);
end
