% Field in an overmoded cavity.
%
% Complement to Figure 3.13c in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Note: This is a short script for illustration of the statistical field
% distribution in a cavity. What is actually shown is the charge coupling
% from a 3D array of charges. The electric field look similar.

% Define constants.
c0 = 2.99792458e8;
mu0 = 4e-7*pi;
eps0 = 1/(mu0*c0^2);

% Define cavity, frequency, and cavity load.
a = 1.0;
b = 0.8;
c = 1.6;
freq = 800e6;
Delta_f1 = 10e6;
sigma = 2*pi*eps0*Delta_f1;
epsilon = eps0 - 1j*sigma/(2*pi*freq);
k = 2*pi*freq*sqrt(mu0*epsilon);

% Define source points.
xs = 0.5*a;
ys = 0.7*b;
zs = 0.2*c;

% Define cut-planes in cavity.
[xo1, yo1, zo1] = ndgrid(0.0:0.01:0.5,          0.4, 0.8:0.01:c  );
[xo2, yo2, zo2] = ndgrid(         0.5, 0.0:0.01:0.4, 0.8:0.01:c  );
[xo3, yo3, zo3] = ndgrid(0.0:0.01:0.5, 0.0:0.01:0.4, 0.8         );
[xo4, yo4, zo4] = ndgrid(0.0:0.01:a  , 0.0         , 0.0:0.01:0.8);
[xo5, yo5, zo5] = ndgrid(0.0         , 0.0:0.01:b  , 0.0:0.01:0.8);
[xo6, yo6, zo6] = ndgrid(0.5:0.01:a  , 0.0         , 0.8:0.01:c  );
[xo7, yo7, zo7] = ndgrid(0.0         , 0.4:0.01:b  , 0.8:0.01:c  );
[xo8, yo8, zo8] = ndgrid(0.0:0.01:a  , 0.4:0.01:b  ,          c  );
[xo9, yo9, zo9] = ndgrid(0.5:0.01:a  , 0.0:0.01:0.4,          c  );

% Calculate Green's function in the planes.
G1 = ewald_3d_array(2*a, 2*b, 2*c, k, xs-xo1, ys-yo1, zs-zo1);
G2 = ewald_3d_array(2*a, 2*b, 2*c, k, xs-xo2, ys-yo2, zs-zo2);
G3 = ewald_3d_array(2*a, 2*b, 2*c, k, xs-xo3, ys-yo3, zs-zo3);
G4 = ewald_3d_array(2*a, 2*b, 2*c, k, xs-xo4, ys-yo4, zs-zo4);
G5 = ewald_3d_array(2*a, 2*b, 2*c, k, xs-xo5, ys-yo5, zs-zo5);
G6 = ewald_3d_array(2*a, 2*b, 2*c, k, xs-xo6, ys-yo6, zs-zo6);
G7 = ewald_3d_array(2*a, 2*b, 2*c, k, xs-xo7, ys-yo7, zs-zo7);
G8 = ewald_3d_array(2*a, 2*b, 2*c, k, xs-xo8, ys-yo8, zs-zo8);
G9 = ewald_3d_array(2*a, 2*b, 2*c, k, xs-xo9, ys-yo9, zs-zo9);

% Normalize.
norm_factor = 1 ./ max([abs(G1(:)) ; abs(G2(:)) ; abs(G3(:)) ; abs(G4(:)) ; ...
    abs(G5(:)) ; abs(G6(:)) ; abs(G7(:)) ; abs(G8(:)) ; abs(G9(:))]);
G1A = abs(G1) * norm_factor;
G2A = abs(G2) * norm_factor;
G3A = abs(G3) * norm_factor;
G4A = abs(G4) * norm_factor;
G5A = abs(G5) * norm_factor;
G6A = abs(G6) * norm_factor;
G7A = abs(G7) * norm_factor;
G8A = abs(G8) * norm_factor;
G9A = abs(G9) * norm_factor;

% Display calculated data.
figure;
surf(squeeze(xo1), squeeze(yo1), squeeze(zo1), squeeze(G1A)); hold on;
surf(squeeze(xo2), squeeze(yo2), squeeze(zo2), squeeze(G2A));
surf(squeeze(xo3), squeeze(yo3), squeeze(zo3), squeeze(G3A));
surf(squeeze(xo4), squeeze(yo4), squeeze(zo4), squeeze(G4A));
surf(squeeze(xo5), squeeze(yo5), squeeze(zo5), squeeze(G5A));
surf(squeeze(xo6), squeeze(yo6), squeeze(zo6), squeeze(G6A));
surf(squeeze(xo7), squeeze(yo7), squeeze(zo7), squeeze(G7A));
surf(squeeze(xo8), squeeze(yo8), squeeze(zo8), squeeze(G8A));
surf(squeeze(xo9), squeeze(yo9), squeeze(zo9), squeeze(G9A));
plot3([0   0  ], [0   0.4], [0.8 0.8], 'k-');
plot3([0   0  ], [0.4 0.4], [0.8 1.6], 'k-');
plot3([0   0.5], [0   0  ], [0.8 0.8], 'k-');
plot3([0   0.5], [0.4 0.4], [0.8 0.8], 'k-');
plot3([0   0.5], [0.4 0.4], [1.6 1.6], 'k-');
plot3([0.5 0.5], [0   0  ], [0.8 1.6], 'k-');
plot3([0.5 0.5], [0   0.4], [0.8 0.8], 'k-');
plot3([0.5 0.5], [0   0.4], [1.6 1.6], 'k-');
plot3([0.5 0.5], [0.4 0.4], [0.8 1.6], 'k-');
colormap(jet(256));
colorbar;
shading interp;
axis image;
box on;
xlabel('x');
ylabel('y');
zlabel('z');
if exist('savefigs', 'var') && savefigs
    save_fig('Fig3-13b.png', 14, 10, 600);
    colormap(flipud(gray(20)));
    save_fig('Fig3-13bgray.png', 14, 10, 600);
end
