% Radiation patterns of an incremental dipole and a halfwave dipole.
%
% Complement to Figure 5.4 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define theta and phi angles.
theta_deg = -180:180;
phi_deg = 0:180;
[theta, phi] = ndgrid(theta_deg*pi/180, phi_deg*pi/180);

% Far-field function (normalized) of a y-directed incremental dipole from
% Eq. (4.70).
G_id_theta = cos(theta) .* sin(phi);
G_id_phi = cos(phi);

% Calculate Eq. (5.12). Fix division with zero problems.
ss = sin(theta).*sin(phi);
jj = cos(0.5*pi*ss) ./ (1-ss.^2);
indx = abs(1-ss.^2) < 1e-8;
jj(indx) = pi/4;  % from Taylor expansion

% Far-field function (normalized) of a y-directed halfwave dipole from
% Eq. (5.11).
G_d_theta = jj .* cos(theta) .* sin(phi);
G_d_phi = jj .* cos(phi);

% Plot radiation patterns when phi==90 degrees.
figure;
plot(theta_deg, 20*log10(abs(G_id_theta(:,phi_deg==90))), 'k--', ...
     theta_deg, 20*log10(abs(G_d_theta (:,phi_deg==90))), 'k-');
axis([-90 90 -30 0]);
grid on;
legend('Incremental dipole', 'Halfwave dipole', 'Location', 'southeast');
xlabel('Theta angle [deg]');
ylabel('Relative E-field [dB]');

% Make 3-D plots.
plot_3d_farfield(theta, phi, G_id_theta, G_id_phi, 'yprim');
annotation('textbox', [0.05,0.05,0.9,0.08], ...
    'string', 'y-directed incremental dipole', 'HorizontalAlignment', 'center');
plot_3d_farfield(theta, phi, G_d_theta , G_d_phi , 'yprim');
annotation('textbox', [0.05,0.05,0.9,0.08], ...
    'string', 'y-directed halfwave dipole', 'HorizontalAlignment', 'center');
