% BOR1 efficiency for a transverse dipole.
%
% Complement to Figure 5.5 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define theta angles, phi angles, and dipole length (with unit wavelength).
% Expand to matrices where dimesion 1 is theta angle variation, dimension 2 is
% phi angle variation, and dimension 3 is dipole length variation. Avoid
% numerical problems by avoiding integer values of dip_len_lambda.
[theta, phi, dip_len_lambda] = ndgrid(linspace(0,pi,81), ...
    linspace(0,2*pi,161), -0.01:0.02:1.01);

% We will need delta theta and delta phi for integration later. It is assumed
% that theta and phi are unispaced.
dtheta = theta(2,1,1) - theta(1,1,1);
dphi = phi(1,2,1) - phi(1,1,1);

% Calculate Fourier transform according to Eq. (5.8).
klh = pi*dip_len_lambda;
lr = sin(theta) .* sin(phi);
jj = (cos(klh.*lr) - cos(klh)) ./ ((1-lr.^2) .* sin(klh));

% Avoid numerical errors. This formla can be derived with Taylor expansion.
indx = abs(1-lr.^2) < 1e-8;
jj(indx) = klh(indx)/2;

% Far-field function from Eq. (5.11).
G_theta = cos(theta) .* sin(phi) .* jj;
G_phi = cos(phi) .* jj;

% Total radiated power from Eq. (2.65).
P_dip = dtheta*dphi*trapz(trapz((G_theta.^2 + G_phi.^2) .* sin(theta)));

% Fourier coefficients.
A1 = (1/pi) * dphi * trapz(G_theta.*sin(phi), 2);
C1 = (1/pi) * dphi * trapz(G_phi.*cos(phi), 2);

% Radiated power of BOR1 mode.
P1 = pi * dtheta * trapz((A1.^2 + C1.^2) .* sin(theta(:,1,:)));

% BOR1 efficiency.
e_BOR1 = P1 ./ P_dip;

% Plot BOR1 efficiency.
figure;
plot(squeeze(dip_len_lambda(1,1,:)), squeeze(10*log10(e_BOR1)), 'b-');
axis([0 1.01 -0.3 0]);
grid on;
xlabel('Dipole length [\lambda]');
ylabel('BOR1 efficiency [dB]');
