% Radiation pattern of a vertical dipole above a GP.
%
% Complement to Figure 5.12 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define angles and height above ground plane (unit wavelength).
theta_deg = -180:180;
phi_deg = 0:180;
h_lambda_vector = [0 0.125 0.25 0.375 0.5 0.75 1];
[theta, phi, h_lambda] = ndgrid(theta_deg*pi/180, phi_deg*pi/180, ...
    h_lambda_vector);

% Far-field function from Eq. (5.56).
kh = 2*pi*h_lambda;
G_vid_theta = sin(theta) .* cos(kh.*cos(theta));
G_vid_theta(cos(theta)<0) = 0;  % below ground plane
G_vid_phi = zeros(size(G_vid_theta));

% Make cell array with legend text.
lgnds = cell(1,numel(h_lambda_vector));
for ii = 1:numel(lgnds)
    lgnds{ii} = sprintf('h = %.3f \\lambda', h_lambda_vector(ii));
end

% Plot radiation pattern in two plots.
for indx = {1:4, 5:numel(h_lambda_vector)}
    figure;
    plot(theta_deg, squeeze(20*log10(abs(G_vid_theta(:,1,indx{1})))));
    axis([-90 90 -40 0]);
    grid on;
    xlabel('\theta [deg]');
    ylabel('Relative E-field [dB]');
    legend(lgnds(indx{1}), 'Location', 'southwest');
end

% First, plot far-field of z-directed incremental dipole for comparison.
G_theta = sin(theta(:,:,1));
G_phi = zeros(size(G_theta));
plot_3d_farfield(theta(:,:,1), phi(:,:,1), G_theta, G_phi, 'theta-phi', 40);
annotation('textbox', [0.05,0.05,0.9,0.08], 'string', 'No ground plane', ...
    'HorizontalAlignment', 'center');

% Plot 3-D radiation patterns.
for ii = 1:numel(h_lambda_vector)
    plot_3d_farfield(theta(:,:,ii), phi(:,:,ii), ...
        G_vid_theta(:,:,ii), G_vid_phi(:,:,ii), 'theta-phi', 40);
    annotation('textbox', [0.05,0.05,0.9,0.08], 'string', lgnds{ii}, ...
        'HorizontalAlignment', 'center');
end
