% Radiation pattern of a horizontal dipole above a GP.
%
% Complement to Figure 5.14 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define angles and height above ground plane (unit wavelength).
theta_deg = -180:180;
phi_deg = 0:180;
h_lambda_vector = [0.001 0.125 0.25 0.375 0.5 0.75 1];
[theta, phi, h_lambda] = ndgrid(theta_deg*pi/180, phi_deg*pi/180, ...
    h_lambda_vector);

% Far-field function from Eq. (5.65).
kh = 2*pi*h_lambda;
G_hid_theta = cos(theta) .* sin(phi) .* sin(kh.*cos(theta));
G_hid_theta(cos(theta)<0) = 0;  % below ground plane
G_hid_phi = cos(phi) .* sin(kh.*cos(theta));
G_hid_phi(cos(theta)<0) = 0;  % below ground plane

% Make cell array with legend text.
lgnds = cell(1,numel(h_lambda_vector));
for ii = 1:numel(lgnds)
    lgnds{ii} = sprintf('h = %.3f \\lambda', h_lambda_vector(ii));
end

% Plot radiation pattern in two plots for phi==90 degrees.
G_hid_dB = squeeze(20*log10(hypot(G_hid_theta(:,phi_deg==90,:), ...
    G_hid_phi(:,phi_deg==90,:))));
G_hid_dB = bsxfun(@minus, G_hid_dB, max(G_hid_dB,[],1));
for indx = {1:4, 5:numel(h_lambda_vector)}
    figure;
    plot(theta_deg, G_hid_dB(:, indx{1}));
    axis([-90 90 -40 2]);
    grid on;
    xlabel('\theta [deg]');
    ylabel('Relative E-field [dB]');
    legend(lgnds(indx{1}), 'Location', 'southeast');
end

% First, plot far-field of y-directed incremental dipole for comparison from
% Eq. (4.70).
G_theta = cos(theta(:,:,1)) .* sin(phi(:,:,1));
G_phi = cos(phi(:,:,1));
plot_3d_farfield(theta(:,:,1), phi(:,:,1), G_theta, G_phi, 'yprim', 40);
annotation('textbox', [0.05,0.05,0.9,0.08], 'string', 'No ground plane', ...
    'HorizontalAlignment', 'center');

% Plot 3-D radiation patterns.
for ii = 1:numel(h_lambda_vector)
    plot_3d_farfield(theta(:,:,ii), phi(:,:,ii), ...
        G_hid_theta(:,:,ii), G_hid_phi(:,:,ii), 'yprim', 40);
    annotation('textbox', [0.05,0.05,0.9,0.08], 'string', lgnds{ii}, ...
        'HorizontalAlignment', 'center');
end
