% Microstrip line.
%
% Complement to Figure 6.3 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define input, width-divided-by-height and relative permittivity.
[w_over_h, eps_r] = ndgrid(logspace(log10(0.1), log10(100), 31), [1 2.54 10]);

% Calculate effective width with Eq. (6.2).
h_over_w = 1 ./ w_over_h;
F = 6 + (2*pi-6) * exp( (-4*pi^2/3) * h_over_w.^(3/4) );
w_eff_over_h = 2*pi ./ log( h_over_w.*F + sqrt(1+(2*h_over_w).^2) );

% Calculate effective relative permittivity with Eq. (6.3).
eps_eff = 0.5*(eps_r+1) + 0.5*(eps_r-1) ./ sqrt(1+10*h_over_w);

% Calculate characteristic impedance and relative guide wavelength with
% Eq. (6.1).
eta = 120*pi;
Z_k = eta ./ ( sqrt(eps_eff) .* w_eff_over_h);
lambda_g_over_lambda = 1 ./ sqrt(eps_eff);

% Prepare legend strings for plots.
lgnds = cell(1, size(eps_r,2));
for ii = 1:size(eps_r,2)
    lgnds{ii} = sprintf('\\epsilon_r = %.2f', eps_r(1,ii));
end

% Plot characteristic impedance.
figure;
semilogx(w_over_h, Z_k);
axis([0.1 100 0 100]);
grid on;
set(gca, 'XTick', 10.^(-1:2));
set(gca, 'XTickLabel', {'0.1','1','10','100'});
legend(lgnds, 'Location', 'northeast');
title('Microstrip');
xlabel('w/h [-]');
ylabel('Characteristic impedance [ohm]');

% Plot relative guide wavelength.
figure;
semilogx(w_over_h, lambda_g_over_lambda);
axis([0.1 100 0 1.1]);
grid on;
set(gca, 'XTick', 10.^(-1:2));
set(gca, 'XTickLabel', {'0.1','1','10','100'});
legend(lgnds, 'Location', 'southeast');
title('Microstrip');
xlabel('w/h [-]');
ylabel('Relative guide wavelength [\lambda_g/\lambda]');
