% Impedance of a patch antenna (two-slot model).
%
% Complement to Figure 6.8 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define dimension patch.
w = 0.4;          % [lambda]
h = [0.05 0.01];  % [lambda]
eps_r = [1 10];

% Define angles and constants.
theta = (0:180)' * pi/180;
phi = (0:180) * pi/180;
[theta2D, phi2D] = ndgrid(theta, phi);
eta = 120*pi;
l_over_l_res = linspace(0.8, 1.2, 401)';
Z_in = zeros(numel(l_over_l_res), numel(h));
lgnds = cell(numel(h), 2);

% Loop through parameters.
for ii = 1:numel(h)

    % Calculate effective parameters.
    F = 6 + (2*pi-6)*exp(-4*pi^2/3*(h(ii)/w)^(3/4));
    w_eff = 2*pi*h(ii) / log(h(ii)*F/w + sqrt(1+(2*h(ii)/w)^2));
    eps_eff = (eps_r(ii)+1)/2 + 0.5*(eps_r(ii)-1)/sqrt(1+10*h(ii)/w);
    Z_k = eta*h(ii) / (sqrt(eps_eff)*w_eff);
    Y_k = 1 / Z_k;
    lambda_guide = 1 / sqrt(eps_eff);
    k_guide = 2*pi / lambda_guide;
    
    % Integration of far-field.
    integrand = (2*cos(0.5*lambda_guide*pi*sin(theta2D).*cos(phi2D))).^2;
    P_phi = phi(2)/pi * trapz(integrand, 2);
    G_patch = theta(2)/(pi*eta) * trapz( sin(pi*w_eff*cos(theta)).^2 .* ...
        sin(theta).^3 .* P_phi ./ cos(theta).^2);
    
    % Equivalent circuit.
    G = G_patch/2;
    Delta_l = 0.412 * h(ii) * (eps_eff+0.300) / (eps_eff-0.258) * ...
        (w_eff/h(ii)+0.262) / (w_eff/h(ii)+0.813);
    
    % Resonant length of patch.
    l_res = lambda_guide/2 - 2*Delta_l;
    
    % Slot capacitance.
    B = k_guide * Delta_l / Z_k;
    
    % Total admittance of slot at one edge.
    Y_edge = G + 1j*B;

    % Calculate input impedance.
    len = l_over_l_res * l_res;
    Y_t = Y_k * (Y_edge + 1j*Y_k*tan(k_guide*len)) ./ ...
                (Y_k + 1j*Y_edge*tan(k_guide*len));
    Z_in(:,ii) = 1 ./ (Y_t + Y_edge);
    
    % Legends for plot.
    tmp = sprintf('\\epsilon_r = %.1f, h = %.2f \\lambda', eps_r(ii), h(ii));
    lgnds{ii,1} = ['R (' tmp ')'];
    lgnds{ii,2} = ['X (' tmp ')'];
end

figure;
plot(l_over_l_res, real(Z_in), '-'); hold on;
plot(l_over_l_res, imag(Z_in), '--');
axis([min(l_over_l_res) max(l_over_l_res) -150 300]);
grid on;
legend(lgnds(:));
xlabel('Length relative resonant length (l/l_{res}) [-]');
ylabel('Impedance [ohm]');
