% Surface plot of the universal radiation pattern of a uniform circular aperture.
%
% Complement to Figure 7.17 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define parameters.
[uu, vv] = ndgrid(-4:0.01:4, -3:0.01:3);
min_dB = -35;

% Calculate using Eq. (7.62).
rho = hypot(uu, vv);
G = 2 * besselj(1, pi*rho) ./ (pi*rho);
G(abs(rho)<1e-8) = 1;
G_dB = max(20*log10(abs(G)), min_dB);

% Find level of first sidelobes. It is the (first) minimum.
r = 1.5:0.0001:1.8;
[~, indx] = min(besselj(1,pi*r)./(pi*r));
r_sidelobe = r(indx);
z_sidelobe_dB = 20*log10(abs(2*besselj(1,pi*r_sidelobe)./(pi*r_sidelobe)));
phi = linspace(-pi, pi, 361);

% Plot a surf plot.
figure;
G_dB(end,end) = -100;  % hack to avoid graphic glitch when saving plot
surf(uu, vv, G_dB);
colormap(jet(-min_dB/2.5));
hold on;
plot3(r_sidelobe*cos(phi), r_sidelobe*sin(phi), ...
    repmat(z_sidelobe_dB+0.1, size(phi)), 'k-');
shading flat;
title('Radiation from a uniform circular aperture');
fs = 8;
% xlabel('$\textsf{u = sin($\theta$) cos($\varphi$) d/$\lambda$}$', 'Interpreter', 'latex', 'fontsize', fs);
% ylabel('$\textsf{v = sin($\theta$) sin($\varphi$) d/$\lambda$}$', 'Interpreter', 'latex', 'fontsize', fs);
xlabel('u = sin(\theta) cos(\phi) d/\lambda', 'Interpreter', 'tex');
ylabel('v = sin(\theta) sin(\phi) d/\lambda', 'Interpreter', 'tex');
view(0, 90);
caxis([min_dB 0]);
hb = colorbar;
axis image;
set(gca, 'TickDir', 'out');
grid off;
box on;
colorTitleHandle = get(hb,'Title');
titleString = 'dB';
set(colorTitleHandle ,'String',titleString);

annotation('textbox', [0.55,0.04,0.4,0.04], 'String', ...
    sprintf('  - First sidelobe %.1f dB at %.3f', ...
    z_sidelobe_dB, r_sidelobe), 'LineStyle', 'none');
set(gca, 'XTickMode', 'manual');
if exist('savefigs', 'var') && savefigs
    save_fig('Fig7-17.png', 14, 10, 1500);
    colormap(flipud(gray(-min_dB/5)));
    save_fig('Fig7-17gray.png', 14, 10, 1500);
end