% Gaussian beam.
%
% Complement to Figure 7.22 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define inputs.
rho_a = 2;  % aperture -8.7 dB radius [m]
L = 40;  % GO cone vertex to aperture distance [m]
lambda = 1;  % wavelength [m]
z = linspace(-L, 100, 400);  % z coordinates [m]
min_dB = -60;

% Index of z coordinates to plot beam.
indx_z = round(linspace(1, numel(z), 7));

% Calculate cone radiuses.
k = 2*pi/lambda;
rho_diff = 2*z/(k*rho_a);  % Eq. (7.83)
rho_GO = (z+L)*rho_a/L;  % Eq. (7.84)
rho = hypot(rho_diff, rho_GO);  % Eq. (7.80)

% Calculate wavefront curvature with Eq. (7.81).
curvature = (1 + (L./z).*(rho_diff./rho).^2) ./ (L+z);
indx1 = abs(z)<1e-8;  % Taylor expansion 1
indx2 = abs(L+z)<1e-8;  % Taylor expansion 2
curvature(indx1) = (1+4*L*z(indx1)/(k*rho_a^2)^2) ./ (L+z(indx1));
curvature(indx2) = 1 ./ z(indx2);

% Calculate phase slippage with Eq. (7.82).
phase_slip = pi/2 - atan2(rho_GO, rho_diff);

% Calculate phase center with Eq. (7.85) and Eq. (7.86).
z_pc = z - 1./curvature;
z_pc_approx = -L * (rho_GO./rho).^2;

% Calculate beam using Eq. (7.79).
r = linspace(-2*max(rho), 2*max(rho), 200);
E = zeros(numel(r), numel(indx_z));
for ii = 1:numel(indx_z)
    iz = indx_z(ii);
    E(:,ii) = (rho_a/rho(iz)) .* exp(-(r/rho(iz)).^2) .* ...
        exp(-1j*k*0.5*curvature(iz)*r.^2) .* exp(1j*phase_slip(iz)) .* ...
        exp(-1j*k*z(iz));
    E(:,ii) = E(:,ii) / max(abs(E(:,ii)));  % normalize for plot
end

figure;
lw = 1;
pl = plot(z, rho_GO, 'k--', z, rho_diff, 'b:', z, rho, 'r-.');
set(pl,'linewidth',lw)
hold on;
for ii = 1:numel(indx_z)
    pl = plot(z(indx_z(ii))+10*abs(E(:,ii)).^2, r, 'g-');
    set(pl,'linewidth',lw)
end
pl = plot(z, -rho_GO, 'k--', z, -rho_diff, 'b:', z, -rho, 'r-.');
set(pl,'linewidth',lw)
xlim([0 max(z)]);
grid off;
title('Gaussian beam: Cones');
xlabel('{\itz} ({\it\lambda})');
ylabel('{\it\rho} ({\it\lambda})');
legend('Geometrical optics (GO) cone', 'Diffraction cone', ...
    'Beam cone (-8.7 dB)', 'Beam shape', 2);
if exist('savefigs', 'var') && savefigs
    save_fig('Fig7-23a.eps', 14, 10, 500, 1, 0, 1);
end 

figure;
plot(z, phase_slip*180/pi, 'k-');
xlim([0 max(z)]);
grid on;
title('Gaussian beam: Phase slippage');
xlabel('z [m]');
ylabel('Phase slippage [deg]');

figure;
plot(z, curvature, 'k-');
xlim([0 max(z)]);
grid on;
title('Gaussian beam: Wavefront curvature');
xlabel('z [m]');
ylabel('Wavefront curvature [1/m]');

figure;
plot(z, z_pc, 'b-', z, z_pc_approx, 'r-');
xlim([0 max(z)]);
grid on;
legend('Exact formula', 'Approximate formula', 4);
title('Gaussian beam: Phase center');
xlabel('z [m]');
ylabel('Phase center [m]');

% Calculate beam using Eq. (7.79).
[r_mat, rho_mat] = ndgrid(r, rho);
zz = repmat(z, numel(r), 1);
EE = (rho_a./rho_mat) .* exp(-(r_mat./rho_mat).^2);
EE_dB = 20*log10(abs(EE));
EE_dB = max(EE_dB, min_dB);
figure;
EE_dB(end,end) = -100;  % hack to avoid graphic glitch when saving plot
surf(zz, r_mat, EE_dB);
colormap(jet(-min_dB/2.5));
title('Gaussian beam: Surface plot (1/r supressed)');
xlabel('{\itz} ({\it\lambda})');
ylabel('{\it\rho} ({\it\lambda})');
shading interp;
caxis([min_dB 0]);
axis([0 max(z) min(r) max(r)]);
view(0, 90);
set(gca, 'TickDir', 'out');
grid off;
box on;
hb = colorbar;
colorTitleHandle = get(hb,'Title');
titleString = 'dB';
set(colorTitleHandle ,'String',titleString);

if exist('savefigs', 'var') && savefigs
    save_fig('Fig7-23b.png', 14, 10, 1500);
    save_fig('Fig7-23b.eps', 14, 10, 500);
    colormap(flipud(gray(-min_dB/5)));
    save_fig('Fig7-23bgray.png', 14, 10, 1500);
    save_fig('Fig7-23bgray.eps', 14, 10, 500);
end