% Aperture field of a smooth conical horn
%
% Complement to Figure 8.20 in Foundations of Antennas by Per-Simon Kildal.

% By Madeleine Kildal Schilliger

% Define u and v.
a = 1;             % a/lambda
u = -a:0.005:a;    % u = sin(theta)cos(phi)a/lambda              
v = -a:0.005:a;    % v = sin(theta)sin(phi)a/lambda
[uu, vv] = ndgrid(u,v);
rho = hypot(uu, vv);         % rho = sin(theta)*a/lambda
phi = atan2(vv, uu);
rho_vector = linspace(0, sqrt(2)*a, 1001);
theta = asin(sqrt(uu.^2 + vv.^2)/a);

% Input parameters.
kappa1 = 1.841;              % besselj(1,x) has maximum at x=kappa1
Phi_max_deg = 90;
Phi_max = Phi_max_deg * pi / 180;
min_dB = -30;

% Calculate the Aperture Field: 
% Eq: (8.49)-(8.52)
Eco45 = besselj(0, kappa1*rho/a);  % Eq. (8.51)
Exp45 = besselj(2, kappa1*rho/a);  % Eq. (8.52)
Eay   = Eco45 - Exp45 .* cos(2*phi); %Eq. (8.49)
Eax   = Exp45 .* sin(2*phi);

Eay(rho > a) = 0;
Eax(rho > a) = 0;

EayRel = Eay / max(abs(Eay(:)));
EaxRel = Eax / max(abs(Eay(:)));

Eay = EayRel;
Eax = EaxRel;

% Plot
figure;
s1 = subplot(1,2,1);
surf(uu, vv, abs(Eay));
colormap(jet(-min_dB/2.5));
shading flat;
grid off;
title('E_y');
% fs = 8;
% xlabel('$\textsf{$\rho/a$}$', 'Interpreter', 'latex', 'FontSize', fs);
% ylabel('$\textsf{$\rho/a$}$', 'Interpreter', 'latex', 'FontSize', fs);
xlabel('\rho/a', 'Interpreter', 'tex');
ylabel('\rho/a', 'Interpreter', 'tex');
view(0, 90);
caxis([0 1]);
axis image;
set(gca, 'TickDir', 'out');
set(gca, 'XTickMode', 'manual');
set(gca, 'XTick', -5:5);
box on;
hold on;
plot(u, sin(acos(u)),'k')
plot(u,-sin(acos(u)),'k')

s2 = subplot(1,2,2);
surf(uu, vv, abs(Eax));
colormap(jet(-min_dB/2.5));
shading flat;
title('E_x');
% fs = 8;
% xlabel('$\textsf{$\rho/a$}$', 'Interpreter', 'latex', 'FontSize', fs);
xlabel('\rho/a', 'Interpreter', 'tex');
view(0, 90);
axis image;
set(gca, 'TickDir', 'out');
set(gca, 'XTickMode', 'manual');
set(gca, 'XTick', -5:5);
grid off;
box on;
hold on;
plot(u, sin(acos(u)),'k')
plot(u,-sin(acos(u)),'k')

s1Pos = get(s1,'position');
set(s1,'position',s1Pos-[0.02 0 0 0])
s2Pos = get(s2,'position');
caxis([0 1]);
hb = colorbar('location','eastoutside');
set(s2,'position',s2Pos-[0.065 0 0 0]);
colorTitleHandle = get(hb,'Title');
titleString = '|E|';
set(colorTitleHandle ,'String',titleString);

ha = axes('Position', [0 0 1 0.85], 'Xlim', [0 1], 'Ylim', [0 1], ...
    'Box', 'off', 'Visible', 'off', 'Units', 'normalized', 'clipping', 'off');
text(0.5, 1,'\bf Smooth conical horn', 'HorizontalAlignment', 'center', ...
    'VerticalAlignment', 'top');

if exist('savefigs', 'var') && savefigs
    save_fig('Fig8-20a.eps', 14, 10, 500);
    save_fig('Fig8-20a.png', 14, 10, 1500);
    colormap(flipud(pink(15)));
    save_fig('Fig8-20agray.eps', 14, 10, 500);
    save_fig('Fig8-20agray.png', 14, 10, 1500);
end
