% Aperture field of a corrugated conical horn
%
% Complement to Figure 8.22 in Foundations of Antennas by Per-Simon Kildal.

% By Madeleine Kildal Schilliger.

% Define u and v.
a = 1;                   % a/lambda
u = -a:0.005:a;          % u = sin(theta)cos(phi)a/lambda              
v = -a:0.005:a;          % v = sin(theta)sin(phi)a/lambda
[uu, vv] = ndgrid(u,v);
rho = hypot(uu,vv);      % rho = sin(theta)*a/lambda
phi = atan(vv ./ uu);
rho_vector = linspace(0, sqrt(2)*a, 1001);


% Input parameters.
kappa01 = 2.405;         % besselj(1,x) has maximum at x=kappa01
Phi_max_deg = 90;
Phi_max = Phi_max_deg * pi / 180;
min_dB = -30;

% Calculate the Aperture Field: 
% Eq: (8.59)
Eay = besselj(0, kappa01*rho/a);
Eax = zeros(size(Eay));

Eay(rho > a) = 0;

Eay = Eay / max(abs(Eay(:)));

% Plot
figure;
s1 = subplot(1,2,1);
surf(uu, vv, abs(Eay));
colormap(jet(-min_dB/2.5));
shading flat;
title('E_y');
% fs = 8;
% xlabel('$\textsf{$\rho/a$}$', ...
%     'Interpreter', 'latex', 'FontSize', fs);
% ylabel('$\textsf{$\rho/a$}$', ...
%     'Interpreter', 'latex', 'FontSize', fs);view(0, 90);
xlabel('\rho/a', 'Interpreter', 'tex');
ylabel('\rho/a', 'Interpreter', 'tex');
view(0, 90);
caxis([0 1]);
axis image;
set(gca, 'TickDir', 'out');
set(gca, 'XTickMode', 'manual');
set(gca, 'XTick', -5:5);
grid off;
box on;
hold on;
plot(u, sin(acos(u)),'k')
plot(u,-sin(acos(u)),'k')

s2 = subplot(1,2,2);
surf(uu, vv, abs(Eax));
colormap(jet(-min_dB/2.5));
shading flat;
title('E_x');
% fs = 8;
% xlabel('$\textsf{$\rho/a$}$', ...
%     'Interpreter', 'latex', 'FontSize', fs);
xlabel('\rho/a', 'Interpreter', 'tex');
view(0, 90);
axis image;
set(gca, 'TickDir', 'out');
set(gca, 'XTickMode', 'manual');
set(gca, 'XTick', -5:5);
grid off;
box on;
hold on;
plot(u, sin(acos(u)),'k')
plot(u,-sin(acos(u)),'k')

s1Pos = get(s1,'position');
set(s1,'position',s1Pos-[0.02 0 0 0])
s2Pos = get(s2,'position');
caxis([0 1]);
hb = colorbar('location','eastoutside');
set(s2,'position',s2Pos-[0.065 0 0 0]);
colorTitleHandle = get(hb,'Title');
titleString = '|E|';
set(colorTitleHandle ,'String',titleString);

ha = axes('Position', [0 0 1 0.85], 'Xlim', [0 1], 'Ylim', [0 1], ...
    'Box', 'off', 'Visible', 'off', 'Units', 'normalized', 'clipping', 'off');
text(0.5, 1,'\bf Corrugated conical horn', 'HorizontalAlignment', 'center', ...
    'VerticalAlignment', 'top');

if exist('savefigs', 'var') && savefigs
    save_fig('Fig8-22a.eps', 14, 10, 500);
    save_fig('Fig8-22a.png', 14, 10, 1500);
    colormap(flipud(pink(15)));
    save_fig('Fig8-22agray.eps', 14, 10, 500);
    save_fig('Fig8-22agray.png', 14, 10, 1500);
end