% Spillover, center blockage, and taper of paraboloid antenna.
%
% Complement to Figure 9.8 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
lambda = 1;  % wavelength [m]
D = 30;         % diameter of reflector [m]
d = 3;          % diameter of sub-reflector (blocking aperture field) [m]
theta_0_deg = 80;       % subtended half angle [deg]
A0_dB = [10 15 20];     % feed illumination taper vector [dB]
plot_range_dB = 70;     % plot range on y-axis [dB]

% Define feed pattern.
theta_0 = theta_0_deg*pi/180;
theta_deg = (-180:0.25:180)';
theta = theta_deg*pi/180;
n_theta = numel(theta);
n_taper = numel(A0_dB);
n = A0_dB / (-20*log10(cos(theta_0/2)));
G_feed = zeros(n_theta, n_taper);
for ii = 1:n_taper
    G_feed(:,ii) = sqrt(n(ii)+1) .* abs(cos((theta+pi)/2)).^n(ii);
end

% Feed pattern with blockage from reflector.
G_feed_blocked = G_feed;
G_feed_blocked(abs(theta)>pi-theta_0,:) = 10^(-100/20);

% Calculate aperture field, assuming no cross-polarization.
F = 0.25 * D / tan(theta_0/2);  % Eq. (9.34)
k = 2*pi/lambda;
drho = lambda/20;
rho = 0:drho:D/2;
n_rho = numel(rho);
theta_f = atan(rho/F);
Gco45_feed = zeros(n_taper, n_rho);
Eco45 = zeros(n_taper, n_rho);
for ii = 1:n_taper
    Gco45_feed(ii,:) = sqrt(1+n(ii)) .* cos(theta_f/2).^n(ii);
    Eco45(ii,:) = (-1/F) * cos(theta_f/2).^2 .* Gco45_feed(ii,:) * exp(-2j*k*F);  % Eq. (9.49)
end

% Calculate radiation by integration of aperture field.
Eco45_tilde = zeros(n_theta, n_taper);
Eco45_tilde_cb = zeros(n_theta, n_taper);    % center blocked
Gco45 = zeros(n_theta, n_taper);
Gco45_cb = zeros(n_theta, n_taper);          % center blocked
[~,is] = min(abs(rho-d/2));  % index to start integration when blocked
for ii = 1:n_taper
    integrand = repmat(Eco45(ii,:).*rho, n_theta, 1) .* besselj(0, k*sin(theta)*rho);
    Eco45_tilde(:,ii) = 2 * pi * drho * trapz(integrand, 2);  % Eq. (7.55)
    Eco45_tilde_cb(:,ii) = 2 * pi * drho * trapz(integrand(:,is:end), 2);  % Eq. (7.55)
    Gco45(:,ii) = Eco45_tilde(:,ii) .* cos(theta/2).^2;
    Gco45_cb(:,ii) = Eco45_tilde_cb(:,ii) .* cos(theta/2).^2;
end

% Define plot range.
D0_max = (pi*D/lambda)^2;
ymax = 10*ceil(log10(D0_max));
ymin = ymax - plot_range_dB;

% Calculate directivity and normalize pattern.
ef = 4 * cot(theta_0/2).^2 * (1-cos(theta_0/2).^n).^2 .* (n+1) ./ n.^2;  % Eq. (9.69)
esp = 1 - cos(theta_0/2).^(2*n+2);  % Eq. (9.70)
D0 = ef .* esp * D0_max;  % Eq. (9.55)
for ii = 1:n_taper
    norm_factor = sqrt(D0(ii)) / max(abs(Gco45(:,ii)));
    Gco45(:,ii) = norm_factor * Gco45(:,ii);
    Gco45_cb(:,ii) = norm_factor * Gco45_cb(:,ii);
end

% Radiation from aperture and feed.
Gco45_tot = Gco45 + G_feed_blocked;
Gco45_cb_tot = Gco45_cb + G_feed_blocked;

% Plot feed pattern.
figure;
h = plot(theta_deg, 20*log10(abs(G_feed)));
hline = findobj(gcf, 'type', 'line');
set(hline(1),'LineStyle','-.','LineWidth',1.5)
set(hline(2),'LineStyle','--','LineWidth',1.5)
set(hline(3),'LineStyle','-','LineWidth',1.5)

hold on;
plot(-180+theta_0_deg, 20*log10(abs(G_feed(1,:)))-A0_dB, 'ko');
plot(+180-theta_0_deg, 20*log10(abs(G_feed(1,:)))-A0_dB, 'ko');
axis([min(theta_deg) max(theta_deg) ymin ymax]);
set(gca, 'XTick', -180:45:180);
grid on;
title('Feed pattern');
xlabel('\theta ( ^{\circ})');
ylabel('Gain (dBi)');
lgnds = cell(n_taper, 1);
for ii = 1:n_taper
    %lgnds{ii} = sprintf('Taper %.0f dB at \\theta_0 = %.0f^\\circ', A0_dB(ii), theta_0_deg);
    lgnds{ii} = sprintf('%.0f dB', A0_dB(ii));
end
hl = legend(lgnds, 1); %'Location',[0.166,0.115,0.1,0.15]);
lPos = get(hl,'Position');
annotation('textbox', [lPos]-[-0.04 0.11 0 0], 'String', 'Taper', 'LineStyle', 'none')
if exist('savefigs', 'var') && savefigs
    save_fig('Fig9-08b1.eps', 14, 8, 500);
end

% Plot blocked feed pattern.
figure;
plot(theta_deg, 20*log10(abs(G_feed_blocked)));
hline = findobj(gcf, 'type', 'line');
set(hline(1),'LineStyle','-.','LineWidth',1.5)
set(hline(2),'LineStyle','--','LineWidth',1.5)
set(hline(3),'LineStyle','-','LineWidth',1.5)

axis([min(theta_deg) max(theta_deg) ymin ymax]);
set(gca, 'XTick', -180:45:180);
grid on;
title('Feed pattern with blockage from reflector');
xlabel('\theta ( ^{\circ})');
ylabel('Gain (dBi)');
hl = legend(lgnds, 1);
lPos = get(hl,'Position');
annotation('textbox', [lPos]-[-0.04 0.11 0 0], 'String', 'Taper', 'LineStyle', 'none')
if exist('savefigs', 'var') && savefigs
    save_fig('Fig9-08b2.eps', 14, 8, 500);
end

%% Plot radiation pattern from aperture.
figure;
plot(theta_deg, 20*log10(abs(Gco45)));
hline = findobj(gcf, 'type', 'line');
set(hline(1),'LineStyle','-.','LineWidth',1.5)
set(hline(2),'LineStyle','--','LineWidth',1.5)
set(hline(3),'LineStyle','-','LineWidth',1.5)

axis([min(theta_deg) max(theta_deg) ymin ymax]);
set(gca, 'XTick', -180:45:180);
grid on;
title('Unblocked aperture pattern');
xlabel('\theta ( ^{\circ})');
ylabel('Gain (dBi)');
hl = legend(lgnds, 1);
lPos = get(hl,'Position');
annotation('textbox', [lPos]-[-0.04 0.11 0 0], 'String', 'Taper', 'LineStyle', 'none')
if exist('savefigs', 'var') && savefigs
    save_fig('Fig9-08c1.eps', 14, 8, 500);
end

%% Plot radiation pattern from aperture and feed.
figure;
plot(theta_deg, 20*log10(abs(Gco45_cb_tot)));
hline = findobj(gcf, 'type', 'line');
set(hline(1),'LineStyle','-.','LineWidth',1.5)
set(hline(2),'LineStyle','--','LineWidth',1.5)
set(hline(3),'LineStyle','-','LineWidth',1.5)

axis([min(theta_deg) max(theta_deg) ymin ymax]);
set(gca, 'XTick', -180:45:180);
grid on;
title('Total radiation pattern (feed+aperture)');
xlabel('\theta ( ^{\circ})');
ylabel('Gain (dBi)');
hl = legend(lgnds, 1);
lPos = get(hl,'Position');
annotation('textbox', [lPos]-[-0.04 0.11 0 0], 'String', 'Taper', 'LineStyle', 'none')
if exist('savefigs', 'var') && savefigs
    save_fig('Fig9-08c2.eps', 14, 8, 500);
end
