% Total efficiency of a Cassegrain antenna.
%
% Complement to Figure 9.15b in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
D = [20 50 100 200 500 Inf];  % main reflector diameter [lambda]
d_rel = 0.05;                 % relative subreflector diameter [-]
A0_dB = (5:0.05:30)';         % feed illumination taper [dB]
Psi_0_deg = 90;               % subtended half angle main reflector [deg]
theta_0_deg = 10;             % subtended half angle subreflector (not critical)
                              % [deg]

% Calculate feed efficiency.
A0 = 10.^(-A0_dB/20);
Psi_0 = Psi_0_deg*pi/180;
theta_0 = theta_0_deg*pi/180;
n = A0_dB / (-20*log10(cos(theta_0/2)));
eff = 4 * (1-A0).^2 .* cot(theta_0/2).^2 .* (1+n) ./ n.^2;

% Calculate blockage and diffraction efficiency.
Cb = n ./ ( 2*cot(theta_0/2)^2*(1-A0));  % blockage parameter Eq. (9.106)
Cd = cos(theta_0/2).^2 * Cb / pi;  % diffraction parameter Eq. (9.110)
Delta_cb = Cb .* d_rel.^2;  % Eq. (9.104)
tmp1 = (1-1j) * Cd .* A0;
tmp2 = sqrt(1./(d_rel*D*sin(Psi_0))) .* sqrt(1-d_rel);
Delta_d = bsxfun(@times, tmp1, tmp2);  % Eq. (9.104)
ebd = abs(1 - repmat(Delta_cb,1,numel(D)) - Delta_d).^2;

% Total efficiency.
etot = repmat(eff,1,numel(D)) .* ebd;

% Plot.
figure;
plot(A0_dB, 10*log10(etot));
axis([min(A0_dB) max(A0_dB) -3 -0.5]);
grid on;
title('Cassegrain antenna');
xlabel('Feed illumination taper [dB]');
ylabel('Aperture efficiency with blockage and diffraction [dB]');
lgnds = cell(numel(D), 1);
for ii = 1:numel(D)
    lgnds{ii} = sprintf('Main reflector diameter %.0f \\lambda', D(ii));
end
legend(lgnds);
