% Radiation pattern of linear phased array.
%
% Complement to Figure 10.8 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Define theta and phi angles.
[theta, phi] = ndgrid(linspace(0,pi,181), linspace(0,2*pi,361));

% Define input for several cases of linear arrays (on z-axis) below:
txt = {[' Single' char(10) 'element'], ['Array with' char(10) ' \alpha_0 = 90^\circ'], ['Array with' char(10) ' \alpha_0 = 60^\circ'], ['Array with' char(10) ' \alpha_0 = 0^\circ']};

% Case 1: Huygens sources pointing in Z-direction.
acase(1).title_str = 'Z-directed Huygens sources';
acase(1).alpha_0_deg = [  0  90  60   0];  % main beam direction from endfire [deg]
acase(1).N           = [  1  10  10  10];  % number of elements in antenna array
acase(1).d           = [0.5 0.5 0.5 0.5];  % element spacing [lambda]
acase(1).text = txt;
acase(1).G_theta =  sqrt(3) * cos(phi) .* cos(theta/2).^2;  % element pattern
acase(1).G_phi   = -sqrt(3) * sin(phi) .* cos(theta/2).^2;  % element pattern

% Help variable used below.
above_yz_gp = sin(theta).*cos(phi) >= 0;

% Case 2: Y-polarized (Z-directed) incremental magnetic dipoles.
acase(2).title_str = 'Z-directed incremental magnetic dipoles on YZ-GP';  % Eq. (4.80)
acase(2).alpha_0_deg = [  0  90  60   0];  % main beam direction from endfire [deg]
acase(2).N           = [  1  10  10  10];  % number of elements in antenna array
acase(2).d           = [0.5 0.5 0.5 0.5];  % element spacing [lambda]
acase(2).text = txt; 
acase(2).G_theta = zeros(size(theta));
acase(2).G_phi = sin(theta) .* above_yz_gp;

% Case 3: Z-polarized (Y-directed) incremental magnetic dipoles.
acase(3).title_str = 'Y-directed incremental magnetic dipoles on YZ-GP';  % Eq. (4.80)
acase(3).alpha_0_deg = [  0  90  60   0];  % main beam direction from endfire [deg]
acase(3).N           = [  1  10  10  10];  % number of elements in antenna array
acase(3).d           = [0.5 0.5 0.5 0.5];  % element spacing [lambda]
acase(3).text = txt;
acase(3).G_theta = cos(phi) .* above_yz_gp;
acase(3).G_phi = -cos(theta) .* sin(phi) .* above_yz_gp;

% Go through cases.
sp = cell(4,1);
for ic = 1:numel(acase)

    % Go through parameters for this case.
    figure;
    for jj = 1:numel(acase(ic).alpha_0_deg)
        alpha_0_deg = acase(ic).alpha_0_deg(jj);
        N = acase(ic).N(jj);
        d = acase(ic).d(jj);

        % Calculate amplitude and phase excitation of each element.
        A = ones(N, 1);  % assume uniform excitation (this can be changed)
        Phi = linspace(0, -2*pi*d*cosd(alpha_0_deg)*(N-1), N)';

        % Add upp contribution from all elements in array.
        GA_theta = zeros(size(acase(ic).G_theta));
        GA_phi = zeros(size(GA_theta));
        for ii = 1:N
            % Eq. (10.4)
            tmp = A(ii) * exp(1j*Phi(ii)) * exp(2j*pi*d*(ii-1)*cos(theta));
            GA_theta = GA_theta + tmp.*acase(ic).G_theta;
            GA_phi   = GA_phi   + tmp.*acase(ic).G_phi;
        end
        
        sp{jj}=subplot(1, numel(acase(ic).alpha_0_deg), jj);
        
        % Plot total field.
        W_dB = 20*log10(hypot(GA_theta,GA_phi));
        W_dB = W_dB - max(W_dB(:));
        range_dB = 15;
        W_dB_scaled = max(W_dB+range_dB,0) / range_dB;
        plot_3d_farfield_sub(theta, phi, W_dB_scaled);
        x_textPos = 1.30;
        y_textPos = -5;
        text(x_textPos,y_textPos,acase(ic).text(jj));
    end

    s1Pos = get(sp{1},'position');
    set(sp{1},'position',s1Pos-[0.05 0 0 0])
    s2Pos = get(sp{2},'position');
    set(sp{2},'position',s2Pos-[0.05 0 0 0])
    s3Pos = get(sp{3},'position');
    set(sp{3},'position',s3Pos-[0.05 0 0 0])
    s4Pos = get(sp{4},'position');
    hb = colorbar('location','eastoutside','YTick', linspace(0,1,4), 'YTickLabel', {'-30', '-20', '-10', '0'});
    set(sp{4},'position',s4Pos-[0.05 0 0 0]);
    hbPos = get(hb,'position');
    set(hb,'position',hbPos+[-0.01 0.233 0.01 -0.50]);
    colorTitleHandle = get(hb,'Title');
    titleString = 'dB';
    set(colorTitleHandle ,'String',titleString);
    
    annotation('textbox', [0.05,0.85,0.9,0.10], 'string', ...
        acase(ic).title_str, 'HorizontalAlignment', 'center', 'LineStyle', 'none');
    
    if exist('savefigs', 'var') && savefigs
        save_fig(sprintf('Fig10-08%c.eps', char(double('a')+ic-1)), 16, 7, 500, 1, 0, 0);
        colormap(flipud(pink(30)));
        save_fig(sprintf('Fig10-08%cgray.eps', char(double('a')+ic-1)), 16, 7, 500, 1, 0, 0);              
    end
end
