% Mutual impedance of two dipoles.
%
% Complement to Figure 10.10 in Foundations of Antennas by Per-Simon Kildal.

% By Ulf Carlberg.

% Input.
d = (0.02:0.01:3)';  % separation [lambda]
len = 0.5;           % length of dipoles [lambda], must be close to 0.5
a = 0.05;            % radius of dipole arms (for colinear case) [lambda]

% Define some parameters and current on dipoles.
k = 2*pi;
eta = 120*pi;
Ck = -1j*k/(4*pi);
zp = linspace(-len/2, len/2, 101);
dzp = zp(2) - zp(1);
[dd, zzp] = ndgrid(d, zp);
curr = sin(k*(len-2*abs(zzp))/2) ./ sin(k*len/2);

% Case 1: Side-by-side dipoles. Calculate double integral.
E1 = zeros(size(dd));
for ii = 1:numel(zp)
    z = zp(ii);
    R = hypot(dd, z-zzp);
    CN1 = 1 + 1./(1j*k*R) - 1./(k*R).^2;
    CN2 = 1 + 3./(1j*k*R) - 3./(k*R).^2;
    int = (CN1 - CN2.*((z-zzp)./R).^2) ./ R;
    E1(:,ii) = Ck * eta * dzp * trapz(curr.*int.*exp(-1j*k*R), 2);
end
Z1 = dzp * trapz(-curr.*E1, 2);

% Case 2: Colinear dipoles. Calculate double integral.
E2 = zeros(size(dd));
for ii = 1:numel(zp)
    z = zp(ii);
    R = hypot(a, z-zzp+dd+len);
    CN1 = 1 + 1./(1j*k*R) - 1./(k*R).^2;
    CN2 = 1 + 3./(1j*k*R) - 3./(k*R).^2;
    int = (CN1 - CN2.*((z-zzp+dd+len)./R).^2) ./ R;
    E2(:,ii) = Ck * eta * dzp * trapz(curr.*int.*exp(-1j*k*R), 2);
end
Z2 = dzp * trapz(-curr.*E2, 2);

% Plot result for side-by-side dipoles.
figure;
plot(d, real(Z1), 'b-', d, imag(Z1), 'r-');
axis([0 max(d) -40 80]);
grid on;
title('Dipoles side-by-side');
xlabel('Separation d [\lambda]');
ylabel('Mutual impedance [ohm]');
legend('Real part', 'Imaginary part');

% Plot result for colinear dipoles.
figure;
plot(d, real(Z2), 'b-', d, imag(Z2), 'r-');
axis([0 1.5 -20 40]);
grid on;
title('Dipoles colinear');
xlabel('Separation d [\lambda]');
ylabel('Mutual impedance [ohm]');
legend('Real part', 'Imaginary part');
