function [Ldip, Zdip] = impedance_dipole_thinwire_gp(Lmin, Lmax, t, a, h, eta_r)
%IMPEDANCE_DIPOLE_THINWIRE_GP Calculates the input impedance of thin wire dipoles over ground plane
%
%   function [Ldip, Zdip] = impedance_dipole_thinwire_gp(Lmin, Lmax, t, a, h, eta_r)
%
%   Input:
%       Lmin  - Minimum length of dipoles [lambda]
%       Lmax  - Maximum length of dipoles [lambda]
%       t     - Segment length [lambda]
%       a     - Radius [lambda]
%       h     - Height over ground plane [lambda]
%       eta_r - Relative impedance of medium [default 1]
%
%   Output:
%       Ldip - Length of dipoles calculated [lambda]
%       Zdip - Input impedances of dipoles [ohm]

if nargin<6, eta_r = 1; end

% Constants.
k = 2*pi;  % all lengths in [lambda]
eta = 120*pi*eta_r;

% Define segments on dipoles.
Nmin = floor(Lmin/t);
Nmax = ceil(Lmax/t);
Ndipoles = Nmax - Nmin + 1;
Ldip = (Nmin:Nmax)'*t;
LL = cell(Ndipoles,1);
for ii = 1:Ndipoles
    N = Nmin + ii - 1;
    LL{ii} = linspace(0, N*t, N)';
end

% Define current on dipoles.
cur = cell(Ndipoles,1);
for ii = 1:Ndipoles
    L = LL{ii}(end);
    cur{ii} = sin(k*(L/2-abs(LL{ii}-L/2)));
end

% Calculate induced transverse electric field.
Et = zeros(Nmax,1);
for iy = 1:2
    if iy==1
        y = a;
        sgn = 1;
    else
        y = 2*h+a;
        sgn = -1;
    end
    Rpp = hypot((0:Nmax-1)'*t  , y);
    Rpm = hypot((0:Nmax-1)'*t+t, y);
    Rmp = hypot((0:Nmax-1)'*t-t, y);
    Rmm = hypot((0:Nmax-1)'*t  , y);
    Psi_q = exp(-1j*k*Rpp)./Rpp - exp(-1j*k*Rpm)./Rpm - ...
            exp(-1j*k*Rmp)./Rmp + exp(-1j*k*Rmm)./Rmm;
    u = linspace(-t/2, t/2, 401)';
    for ii = 1:numel(Et)
        R = hypot((ii-1)*t+u, y);
        Psi_j = sgn * (u(2)-u(1)) * trapz(exp(-1j*k*R)./R);
        Et(ii) = Et(ii) + 1j * eta * (k*t*Psi_j-Psi_q(ii)/k) / (4*pi);
    end
end

% For each dipole, calculate a double integral to get input impedance.
Zdip = zeros(Ndipoles,1);
for idipole = 1:Ndipoles
    Nseg = numel(cur{idipole});
    for m = 1:Nseg
        mn = abs(m-(1:Nseg)');
        Em = sum(Et(mn+1).*cur{idipole});
        Zdip(idipole) = Zdip(idipole) + Em*cur{idipole}(m);
    end
end

end
