function plot_3d_farfield(theta, phi, G_theta, G_phi, pol, range_dB)
%PLOT_3D_FARFIELD Plot 3-D far-field ("radiation pattern") of antenna.
%
%   function plot_3d_farfield(theta, phi, G_theta, G_phi, pol, range_dB)
%
%   Creates new figure and plots the total far-field as defined by the
%   input parameters. All input parameters are 2-D matrices with theta
%   variation in dimension 1 and phi variation in dimension 2.
%
%   The plots are always normalized and in dB.

% By Ulf Carlberg.

% Default values for optional arguments.
if nargin<6, range_dB = 30; end

% Calculate co-polar and xp-polar fields.
if strcmpi(pol, 'xprim')
    info = {'CO: G_{x''} [dB]', 'XP: G_{y''} [dB]'};
    G_co = cos(phi).*G_theta - sin(phi).*G_phi;  % Eq. (2.53)
    G_xp = sin(phi).*G_theta + cos(phi).*G_phi;
elseif strcmpi(pol, 'yprim')
    info = {'CO: G_{y''} [dB]', 'XP: G_{x''} [dB]'};
    G_co = sin(phi).*G_theta + cos(phi).*G_phi;  % Eq. (2.55)
    G_xp = cos(phi).*G_theta - sin(phi).*G_phi;  % Eq. (2.56)
elseif strcmpi(pol, 'RHC')
    info = {'CO: G_{RHC} [dB]', 'XP: G_{LHC} [dB]'};
    G_co = (G_theta + 1j*G_phi) / sqrt(2);  % Eq. (2.57)
    G_xp = (G_theta - 1j*G_phi) / sqrt(2);  % Eq. (2.58)
elseif strcmpi(pol, 'LHC')
    info = {'CO: G_{LHC} [dB]', 'XP: G_{RHC} [dB]'};
    G_co = (G_theta - 1j*G_phi) / sqrt(2);  % Eq. (2.59)
    G_xp = (G_theta + 1j*G_phi) / sqrt(2);  % Eq. (2.60)
elseif strcmpi(pol, 'theta-phi')
    info = {'G_\theta [dB]', 'G_\phi [dB]'};
    G_co = G_theta;
    G_xp = G_phi;
end    

% Calculate normalized pattern in dB.
W_co_dB = 20*log10(abs(G_co));
W_xp_dB = 20*log10(abs(G_xp));
tmp = max(W_co_dB(:));
W_co_dB = W_co_dB - tmp;
W_xp_dB = W_xp_dB - tmp;

% Scale and limit pattern to [0, 1] range.
W_co_dB_scaled = max(W_co_dB+range_dB,0) / range_dB;
W_xp_dB_scaled = max(W_xp_dB+range_dB,0) / range_dB;

% Make new figure with 3-D plot.
figure;
subplot(1,2,1);
plot_3d_farfield_sub(theta, phi, W_co_dB_scaled)
annotation('textbox', [0.05,0.15,0.4,0.08], 'string', info{1}, ...
    'HorizontalAlignment', 'center');
subplot(1,2,2);
plot_3d_farfield_sub(theta, phi, W_xp_dB_scaled)
annotation('textbox', [0.55,0.15,0.4,0.08], 'string', info{2}, ...
    'HorizontalAlignment', 'center');

end
