function plot_contour_farfield(theta, phi, G_theta, G_phi, pol, range_dB)
%PLOT_CONTOUR_FARFIELD Plot 3-D far-field ("radiation pattern") of antenna.
%
%   function plot_contour_farfield(theta, phi, G_theta, G_phi, pol, range_dB)
%
%   Creates new figure and plots the total far-field as defined by the
%   input parameters. All input parameters are 2-D matrices with theta
%   variation in dimension 1 and phi variation in dimension 2.
%
%   The plots are always normalized and in dB.

% By Madeleine Schilliger Kildal.

% Default values for optional arguments.
if nargin<6, range_dB = 30; end

% Calculate co-polar and xp-polar fields.
if strcmpi(pol, 'xprim')
    info = {'CO: G_{x''}', 'XP: G_{y''}'};
    G_co = cos(phi).*G_theta - sin(phi).*G_phi;  % Eq. (2.53)
    G_xp = sin(phi).*G_theta + cos(phi).*G_phi;
elseif strcmpi(pol, 'yprim')
    info = {'CO: G_{y''}', 'XP: G_{x''}'};
    G_co = sin(phi).*G_theta + cos(phi).*G_phi;  % Eq. (2.55)
    G_xp = cos(phi).*G_theta - sin(phi).*G_phi;  % Eq. (2.56)
elseif strcmpi(pol, 'RHC')
    info = {'CO: G_{RHC}', 'XP: G_{LHC}'};
    G_co = (G_theta + 1j*G_phi) / sqrt(2);  % Eq. (2.57)
    G_xp = (G_theta - 1j*G_phi) / sqrt(2);  % Eq. (2.58)
elseif strcmpi(pol, 'LHC')
    info = {'CO: G_{LHC}', 'XP: G_{RHC}'};
    G_co = (G_theta - 1j*G_phi) / sqrt(2);  % Eq. (2.59)
    G_xp = (G_theta + 1j*G_phi) / sqrt(2);  % Eq. (2.60)
elseif strcmpi(pol, 'theta-phi')
    info = {'G_\theta', 'G_\phi'};
    G_co = G_theta;
    G_xp = G_phi;
end    

% Calculate pattern in dB.
G_co_dB = 20*log10(abs(G_co));
G_xp_dB = 20*log10(abs(G_xp));
G_co_dB_temp = G_co_dB;
G_co_dB = G_co_dB - max(G_co_dB_temp(:));
G_xp_dB = G_xp_dB - max(G_co_dB_temp(:));
G_co_dB = max(G_co_dB,-range_dB);
G_xp_dB = max(G_xp_dB,-range_dB);

% Make new figure with 3-D plot.
figure;
s1=subplot(1,2,1);
plot_contour_farfield_sub(theta, phi, G_co_dB)
xlabel('u = sin(\theta) cos(\phi)', 'interpreter', 'tex')
ylabel('v = sin(\theta) sin(\phi)', 'interpreter', 'tex');
% xlabel('$\textsf{u = sin($\theta$) cos($\varphi$)}$', 'Interpreter', 'latex', 'FontSize', fs);
% ylabel('$\textsf{v = sin($\theta$) sin($\varphi$)}$', 'Interpreter', 'latex', 'FontSize', fs);
title(info{1});

s2=subplot(1,2,2);
plot_contour_farfield_sub(theta, phi, G_xp_dB)
xlabel('u = sin(\theta) cos(\phi)', 'interpreter', 'tex')
% xlabel('$\textsf{u = sin($\theta$) cos($\varphi$)}$', 'Interpreter', 'latex', 'FontSize', fs);
title(info{2});

s1Pos = get(s1,'position');
set(s1,'position',s1Pos-[0.02 0 0 0])
s2Pos = get(s2,'position');
hb = colorbar('location','eastoutside');
set(s2,'position',s2Pos-[0.065 0 0 0]);
colorTitleHandle = get(hb,'Title');
titleString = 'dB';
set(colorTitleHandle ,'String',titleString);